@@ -2,7 +2,7 @@
 
 import os
 
-from akerbp.mlops.cdf.helpers import download_file, set_up_cdf_client 
+import akerbp.mlops.cdf.helpers as helpers
 
 
 if __name__ == "__main__":
@@ -12,5 +12,5 @@ if __name__ == "__main__":
     
     id = int(os.environ['FUNCTION_FILE_ID'])
     
-    set_up_cdf_client()
-    download_file(dict(id=id), f'./{id}.zip')
\ No newline at end of file
+    helpers.set_up_cdf_client()
+    helpers.download_file(dict(id=id), f'./{id}.zip')
\ No newline at end of file
