@@ -146,6 +146,7 @@ def create_function_from_folder(
     folder, 
     handler_path,  
     description='',
+    metadata={},
     owner='',
     secrets={}
 ):
@@ -154,13 +155,14 @@ def create_function_from_folder(
     external id is deleted first.
 
     Inputs:
-      - human_readable_name: name of function to create
-      - function_name: external id of function to create
-      - folder: path where the source code is located
-      - handler_path: path to the handler file
+      - human_readable_name (str): name of function to create
+      - function_name (str): external id of function to create
+      - folder (str): path where the source code is located
+      - handler_path (str): path to the handler file
       - description: (string) function documentation
-      - owner: (string) the function's owner's email
-      - secrets: api keys or similar that should be passed to the function
+      - metadata: (Dict[str, str])
+      - owner: (str) the function's owner's email
+      - secrets (Dict[str, Any]): api keys or similar that should be passed to the function
     """
     client = global_client["functions"]
     try:
@@ -175,6 +177,7 @@ def create_function_from_folder(
         function_path=handler_path,
         external_id=function_name,
         description=description,
+        metadata=metadata,
         owner=owner,
         secrets=secrets,
         env_vars=env_vars
@@ -191,6 +194,7 @@ def create_function_from_file(
     function_name, 
     file_id, 
     description,
+    metadata,
     owner,
     secrets={}
 ):
@@ -214,6 +218,7 @@ def create_function_from_file(
         file_id=file_id,
         external_id=function_name,
         description=description,
+        metadata=metadata,
         owner=owner,
         secrets=secrets,
         env_vars=env_vars
@@ -255,7 +260,7 @@ def deploy_function(
     folder='.',
     handler_path='handler.py',
     secrets=api_keys,
-    info={'description':'', 'owner':''}
+    info={'description':'', 'metadata': {}, 'owner':''}
 ):
     """
     Deploys a Cognite function from a folder. 
@@ -266,19 +271,32 @@ def deploy_function(
       - folder: path where the source code is located
       - handler_path: path to the handler file
       - secrets: api keys or similar that should be passed to the function
+      - info: dictionary containig info for a specifig service, as specified in the setting
     """
     try:
-        metadata=info["metadata"]
+        description = info["description"]
+    except KeyError:
+        raise Exception("Description field is missing, please update mlops_settings.yaml") from None
+
+    try:
+        owner = info["owner"]
+    except KeyError:
+        raise Exception("Owner field is missing, please update mlops_settings.yaml") from None
+
+    try:
+        metadata=json.loads(info["metadata"])
     except KeyError:
         raise Exception("Metadata field is missing, please update mlops_settings.yaml") from None
+
     f = functools.partial(
         create_function_from_folder,
         human_readable_name,
         function_name, 
         folder, 
         handler_path, 
+        description,
         metadata,
-        info['owner'],
+        owner,
         secrets
     )
     robust_create(f)
@@ -289,6 +307,7 @@ def redeploy_function(
     function_name,
     file_id,
     description,
+    metadata,
     owner,
     secrets=api_keys
 ):
@@ -296,9 +315,11 @@ def redeploy_function(
     Deploys a Cognite function from a folder. 
 
     Inputs:
-      - function_name: name of the function to create
-      - file_id: (int) the id for the function file in CDF Files
-      - owner: (string) the function's owner's email
+      - function_name (str): name of the function to create
+      - file_id (int): the id for the function file in CDF Files
+      - owner (str): the function's owner's email
+      - description (str): function description
+      - metadata (Dict[str, str]): dictionary containing function metadata
       - secrets: (optional) api keys or similar that should be passed to the
         function
     """
@@ -308,13 +329,14 @@ def redeploy_function(
         function_name, 
         file_id, 
         description,
+        metadata,
         owner,
         secrets
     )
     robust_create(f)      
 
 
-def get_function_metadata(function_id):
+def get_function_call_response_metadata(function_id):
     """
     Generate metadata for a function
     Input:
