@@ -10,17 +10,37 @@ env = config.envs.env
 logging=logger.get_logger(name='mlops_model_manager')
 
 
-def setup(cdf_api_keys=None):
+dataset_id = 'mlops'
+
+
+def setup(cdf_api_keys=None, dataset_external_id='mlops'):
     """
-    Set up the model manager. Currently this involves only setting up the CDF
-    client. 
+    Set up the model manager. This involves setting up the CDF client and the
+    dataset used to store artifacts.
     
     Input:
         - cdf_api_keys: dictionary with cdf keys
+        - dataset_external_id: (str) external id for the dataset (use None 
+            for no dataset)
     """
     if cdf_api_keys:
         cdf.api_keys = cdf_api_keys
     cdf.set_up_cdf_client()
+    set_active_dataset(dataset_external_id)
+
+
+def set_active_dataset(external_id):
+    """
+    Set current active dataset
+    
+    Input:
+        - external_id: (str) external id for the dataset (use None for no
+            dataset)
+    """
+    global dataset_id
+    dataset_id = cdf.get_dataset_id(external_id)
+    m = f"Active dataset: {external_id=}, {dataset_id=}"
+    logging.debug(m)
 
 
 def upload_new_model_version(model_name, env, folder, metadata={}):
@@ -42,7 +62,8 @@ def upload_new_model_version(model_name, env, folder, metadata={}):
     file_list = cdf.query_file_versions(
         external_id_prefix= f"{model_name}/{env}/", 
         directory_prefix='/mlops', 
-        uploaded=None # count any file
+        uploaded=None, # count any file
+        dataset_id=dataset_id
     )
     if not file_list.empty:
         latest_v = file_list.metadata.apply(lambda d:int(d["version"])).max()
@@ -65,7 +86,8 @@ def upload_new_model_version(model_name, env, folder, metadata={}):
         external_id, 
         folder, 
         metadata,
-        target_folder='/mlops'
+        target_folder='/mlops',
+        dataset_id=dataset_id
     )
     logging.info(f"Uploaded model with {external_id=} from {folder}")
     return folder_info
@@ -86,7 +108,8 @@ def find_model_version(model_name, env, metadata):
     file_list = cdf.query_file_versions(
         directory_prefix='/mlops', 
         external_id_prefix=f"{model_name}/{env}",
-        metadata=metadata
+        metadata=metadata,
+        dataset_id=dataset_id
     )
 
     if (n_models := file_list.shape[0]) == 0:
@@ -100,19 +123,28 @@ def find_model_version(model_name, env, metadata):
     return external_id
 
 
-def download_model_version(model_name, env, folder, metadata={}):
+def download_model_version(model_name, env, folder, metadata={}, version=None):
     """
-    Download a model version to a folder. First the model's external id is
-    found, and then it is downloaded to the chosen folder (creating the folder
-    if necessary).
+    Download a model version to a folder. First the model's external id is found
+    (unless provided by the user), and then it is downloaded to the chosen
+    folder (creating the folder if necessary).
 
     Input: 
         -model_name: name of the model 
         -env: name of the environment ('dev', 'test', 'prod')
-        -folder: (Path) path to folder where the content will be uploaded
-        -metadata: query to the metadata (dictionary)
+        -folder: (Path or str) path to folder where the content will be uploaded
+        -metadata: query to the metadata (dictionary), doesn't make sense when
+            passing a version (see next parameter)
+        -version: (int, optional) if given, this is the version to download
     """
-    external_id = find_model_version(model_name, env, metadata)
+    if isinstance(folder, str):
+        folder = Path(folder)
+    
+    if version:
+        external_id = f"{model_name}/{env}/{version}"
+    else:
+        external_id = find_model_version(model_name, env, metadata)
+
     if not folder.exists():
         folder.mkdir()
     cdf.download_folder(external_id, folder)
@@ -166,7 +198,8 @@ def get_model_version_overview(model_name=None, env=None, metadata={}):
         directory_prefix='/mlops', 
         external_id_prefix=None,
         uploaded=None,
-        metadata=metadata
+        metadata=metadata,
+        dataset_id=dataset_id
     )
 
     # query the external id
@@ -176,6 +209,9 @@ def get_model_version_overview(model_name=None, env=None, metadata={}):
     if env:
         index = file_list.externalId.str.contains("/" + env + "/")
         file_list = file_list.loc[index]
+    if not dataset_id:
+        index = file_list.dataSetId.isnull()
+        file_list = file_list.loc[index]
     return file_list
 
 
@@ -244,7 +280,7 @@ def promote_model(model_name, version, confirm=True):
         - version: (int or str) model's version in test
     """
     external_id = f"{model_name}/test/{version}"
-    if not cdf.file_exists(external_id, '/mlops'):
+    if not cdf.file_exists(external_id, '/mlops', dataset_id):
         return
 
     confirmed = False
@@ -254,4 +290,4 @@ def promote_model(model_name, version, confirm=True):
 
     target_ext_id = f"{model_name}/prod/{version}"
     if not confirm or confirmed:
-        cdf.copy_file(external_id, target_ext_id)
\ No newline at end of file
+        cdf.copy_file(external_id, target_ext_id, dataset_id=dataset_id)
\ No newline at end of file
